@@ -46,6 +46,7 @@ CEcaIAManager::CEcaIAManager()
   nTimerIDFinished = 0;
   nMasterPosition = 0;
   rStatus = NotRunning;
+  nBufferSize = 1024;
   //! \todo 󥻥åȥå "TEMP" ơ
   //! (ÿ֤)νԤ
 }
@@ -97,6 +98,38 @@ CEcaIAManager::numberOfOutputs()
 
 /////////////////////////////////////////////////////////////////////////////
 
+CSourceFormat 
+CEcaIAManager::soundSourceFormat() const
+{
+  return formatRecording;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+int
+CEcaIAManager::bufferSize() const
+{
+  return nBufferSize;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void 
+CEcaIAManager::setSoundSourceFormat(const CSourceFormat& format)
+{
+  formatRecording = format;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
+void 
+CEcaIAManager::setBufferSize(int nSize)
+{
+  nBufferSize = nSize;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 CEcaIAManager::slotCreateNewChainsetup(const QString& strChainsetup)
 {
@@ -154,6 +187,8 @@ CEcaIAManager::slotPlay(bool bRecord)
     rStatus = Playing;
   }
 
+  command("cs-set-audio-format " + formatRecording.sourceFormatInString());
+  command("cs-set-param -b:" + QString("%1").arg(nBufferSize));
   command("cs-connect");
   command("start");
 }
@@ -617,7 +652,7 @@ CEcaIAManager::slotChangeStartPosition(
     return;
   }
 
-  vTrackChains[nIndex].TimeStartPosition = startPosition;
+  vTrackChains[nIndex].timeStartPosition = startPosition;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -633,7 +668,7 @@ CEcaIAManager::slotChangeOffset(
     return;
   }
 
-  vTrackChains[nIndex].TimeOffset = offset;
+  vTrackChains[nIndex].timeOffset = offset;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -649,7 +684,7 @@ CEcaIAManager::slotChangeLength(
     return;
   }
 
-  vTrackChains[nIndex].TimeLength = length;
+  vTrackChains[nIndex].timeLength = length;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -843,7 +878,7 @@ CEcaIAManager::setIOToCurrentChainsetup(bool bRecord)
 
 void 
 CEcaIAManager::setMixdownIOToCurrentChainsetup(
-  bool bWithPlaying, 
+  bool, // not use
   const QString& strFileName)
 {
   prepareTracks();
@@ -984,17 +1019,17 @@ CEcaIAManager::writeEwf(int nIndex, const QString& strFileName)
   strBuffer += DQ + vTrackChains[nIndex].strFileName + DQ + "\n";
   fileEwf.writeBlock(strBuffer.ascii(), qstrlen(strBuffer));
 
-  QTime time = vTrackChains[nIndex].TimeOffset;
+  QTime time = vTrackChains[nIndex].timeOffset;
   strBuffer = "offset = ";
   strBuffer += QString("%1").arg(time.secsTo(time)) + ".0\n";
   fileEwf.writeBlock(strBuffer.ascii(), qstrlen(strBuffer));
 
-  time = vTrackChains[nIndex].TimeStartPosition;
+  time = vTrackChains[nIndex].timeStartPosition;
   strBuffer = "start-position = ";
   strBuffer += QString("%1").arg(time.secsTo(time)) + ".0\n";
   fileEwf.writeBlock(strBuffer.ascii(), qstrlen(strBuffer));
 
-  time = vTrackChains[nIndex].TimeLength;
+  time = vTrackChains[nIndex].timeLength;
   strBuffer = "length = ";
   strBuffer += QString("%1").arg(time.secsTo(time)) + ".0\n";
   fileEwf.writeBlock(strBuffer.ascii(), qstrlen(strBuffer));
