@@ -19,6 +19,7 @@
 
 #include <qstring.h>
 #include <qdatetime.h>
+#include <csourceformat.h>
 
 /*-------------------------------------------------------------------------*/
 /*! \class  CTrackInf
@@ -44,11 +45,11 @@ public:
   //! ѥ
   int  nPan;
   //! ϰ()
-  QTime TimeStartPosition;
+  QTime timeStartPosition;
   //! եåȡ
-  QTime TimeOffset;
+  QTime timeOffset;
   //! ֡
-  QTime TimeLength;
+  QTime timeLength;
   //! ߥ塼Ⱦ֡
   bool bMute;
   //! ϿݡȾ֡
