@@ -166,6 +166,9 @@ WVoxBase::addTrack(
   connect(VoxTrackNew, SIGNAL(lengthChanged(const QTime&)), 
           SignalMapperLength, SLOT(map()));
 
+  connect(VoxTrackNew, SIGNAL(propertyDemanded(const CTrackInf&)),
+          this, SLOT(slotDisplayProperty(const CTrackInf&)));
+
   connect(VoxTrackNew, SIGNAL(locatorScrolled(QObject*, int)), 
           this, SLOT(slotSetScrollToAll(QObject*, int)));
 
@@ -231,6 +234,9 @@ WVoxBase::addTracks(const QDomNode& nodTracks)
     connect(VoxTrackNew, SIGNAL(lengthChanged(const QTime&)),
             SignalMapperLength, SLOT(map()));
 
+    connect(VoxTrackNew, SIGNAL(propertyDemanded(const CTrackInf&)),
+            this, SLOT(slotDisplayProperty(const CTrackInf&)));
+
     connect(VoxTrackNew, SIGNAL(locatorScrolled(QObject*, int)), 
             this, SLOT(slotSetScrollToAll(QObject*, int)));
 
@@ -439,13 +445,19 @@ WVoxBase::setupWidgets()
   VBoxTracks->setMinimumHeight(300);
   ScrollView->addChild(VBoxTracks);
 
+  // >>>> setup bottom tab
   Tab = new QTabWidget(Splitter);
   Tab->setTabPosition(QTabWidget::Bottom);
+
   //  TextEditCmdLine = new KTextEdit(Tab);
   //  Tab->addTab(TextEditCmdLine, "Commandline");
   TextEditEcasound = new KTextEdit(Tab);
   TextEditEcasound->setReadOnly(true);
   Tab->addTab(TextEditEcasound, i18n("Ecasound console"));
+
+  TrackProperty = new WTrackProperty(Tab);
+  Tab->addTab(TrackProperty, i18n("Track property"));
+  // <<<< setup bottom tab
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -786,6 +798,15 @@ WVoxBase::slotChangeLength(const QString& strTrackName)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxBase::slotDisplayProperty(const CTrackInf& trackInf)
+{
+  TrackProperty->slotSetTrack(trackInf);
+  Tab->setCurrentPage(1);
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxBase::slotSetScrollToAll(QObject* ObjectSender, int x)
 {
