@@ -26,6 +26,7 @@
 #include <qdom.h>
 #include <ktextedit.h>
 #include "wvoxtrack.h"
+#include "wtrackproperty.h"
 #include "ctrackinf.h"
 
 /*-------------------------------------------------------------------------*/
@@ -149,6 +150,8 @@ private:
   KTextEdit     *TextEditCmdLine;
   //! EcasoundνϷ̤ɽΰ衣
   KTextEdit     *TextEditEcasound;
+  //! ȥåץѥƥɽ뤿Υåȡ
+  WTrackProperty *TrackProperty;
   //! ȥåץ쥤ХåǥХ̾ѹΤΥʥޥåѡ
   QSignalMapper *SignalMapperPlayback;
   //! ȥå쥳ǥ󥰥ǥХ̾ѹΤΥʥޥåѡ
@@ -248,6 +251,9 @@ private slots:
   //! ǥʥȯ롣
   //! \param strTrackName ȥå̾Ρ
   void slotChangeLength(const QString& strTrackName);
+  //! \brief ץѥƥɽ륹åȡ
+  //! \param trackInf ȥå
+  void slotDisplayProperty(const CTrackInf& trackInf);
 
   //! \brief ȥåΥΥ碌륹åȡ
   void slotSetScrollToAll(QObject* ObjectSender, int x);
