@@ -219,6 +219,13 @@ WVoxTrack::setupPopupMenu()
                         this, SLOT(slotChangeOffset()));
   nMenuIDLength = PopupMenu->insertItem(i18n("Change Playing Time &Length..."),
                         this, SLOT(slotChangeLength()));
+
+  PopupMenu->insertSeparator();
+
+  nMenuIDProperty = PopupMenu->insertItem(
+                        i18n("&View Property of This Track"), 
+			this, 
+                        SLOT(slotProperty()));
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -669,6 +676,16 @@ WVoxTrack::mousePressEvent(QMouseEvent* MouseEvent)
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxTrack::mouseDoubleClickEvent(QMouseEvent* MouseEvent)
+{
+  if ( MouseEvent->button() == Qt::LeftButton ) {
+    slotProperty();
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxTrack::slotSetEnabledWidgets(unsigned int unWidgets, bool bEnabled)
 {
@@ -850,6 +867,14 @@ WVoxTrack::slotChangeLength()
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxTrack::slotProperty()
+{
+  emit propertyDemanded(stateInTrackInf());
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxTrack::slotMovedContents(int x)
 {
